<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Nederlands [NL]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=429
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Dutch';
$lang_info['country'] = 'Nederland';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'nl';
$lang_info['zero_plural'] = true;

$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d categorie bijgewerkt';
$lang['%d albums updated'] = '%d categorieën bijgewerkt';
$lang['%d comment to validate'] = '%d commentaar voor validatie';
$lang['%d comments to validate'] = '%d commentaren voor validatie';
$lang['%d new comment'] = '%d nieuw commentaar';
$lang['%d new comments'] = '%d nieuw commentaar';
$lang['%d comment'] = '%d commentaar';
$lang['%d comments'] = '%d commentaren';
$lang['%d hit'] = '%d bezoeker';
$lang['%d hits'] = '%d bezoekers';
$lang['%d new photo'] = '%d nieuwe afbeelding';
$lang['%d new photos'] = '%d nieuwe afbeeldingen';
$lang['%d new user'] = '%d nieuwe gebruiker';
$lang['%d new users'] = '%d nieuwe gebruikers';
$lang['About'] = 'Over';
$lang['All tags'] = 'Alle tags';
$lang['Any tag'] = 'Elke tag';
$lang['At least one listed rule must be satisfied.'] = 'Op zijn minst moet aan één regel worden voldaan.';
$lang['At least one tag must match'] = 'Op zijn minst moet een tag kloppen';
$lang['Author'] = 'Maker';
$lang['Albums'] = 'Categorieën';
$lang['Album'] = 'Categorie';
$lang['Close this window'] = 'Sluit dit venster';
$lang['Complete RSS feed (photos, comments)'] = 'Complete RSS feed (afbeeldingen, commentaar)';
$lang['Confirm Password'] = 'Bevestig wachtwoord';
$lang['Connection settings'] = 'Verbindings-instellingen';
$lang['Login'] = 'Verbinding';
$lang['Contact webmaster'] = 'Neem contact op met de webbeheerder';
$lang['Create a new account'] = 'Maak een nieuw account aan';
$lang['Created on'] = 'Aangemaakt op';
$lang['Creation date'] = 'Aanmaakdatum';
$lang['Current password is wrong'] = 'Huidig wachtwoord is niet juist';
$lang['Dimensions'] = 'Dimensies';
$lang['Display'] = 'Weergeven';
$lang['Each listed rule must be satisfied.'] = 'Aan elke weergegeven regel moet worden voldaan.';
$lang['Email address is missing. Please specify an email address.'] = 'Email-adres is niet ingevuld';
$lang['Email address'] = 'Email-adres';
$lang['Enter your personnal informations'] = 'Vul uw persoonlijke informatie in';
$lang['Error sending email'] = 'Fout bij het versturen van email';
$lang['File name'] = 'Bestandsnaam';
$lang['File'] = 'Bestand';
$lang['Filesize'] = 'Bestandsgrootte';
$lang['Filter and display'] = 'Filteren en tonen';
$lang['Filter'] = 'Filter';
$lang['Forgot your password?'] = 'Wachtwoord vergeten?';
$lang['Go through the gallery as a visitor'] = 'Ga naar de galerie als gast';
$lang['Help'] = 'Help';
$lang['Identification'] = 'Administratie';
$lang['Photos only RSS feed'] = 'Alleen RSS feed mbt afbeeldingen';
$lang['Keyword'] = 'Sleutelwoord';
$lang['Links'] = 'Links';
$lang['N/A'] = 'Niet bekend';
$lang['New on %s'] = 'Nieuw op %s';
$lang['New password confirmation does not correspond'] = 'Nieuw wachtwoord bevestiging komt niet overeen';
$lang['Notification'] = 'Meldingen';
$lang['Number of items'] = 'Aantal items';
$lang['Original dimensions'] = 'Originele dimensies';
$lang['Password forgotten'] = 'Wachtwoord vergeten';
$lang['Password'] = 'Wachtwoord';
$lang['Post date'] = 'Plaatsingsdatum';
$lang['Posted on'] = 'Geplaatst op';
$lang['Profile'] = 'Profiel';
$lang['Quick connect'] = 'Snel inloggen';
$lang['RSS feed'] = 'RSS feed';
$lang['Register'] = 'Registreren';
$lang['Registration'] = 'Registratie';
$lang['Related tags'] = 'Aanverwante tags';
$lang['Reset'] = 'Reset';
$lang['Retrieve password'] = 'Ontvang nieuw wachtwoord';
$lang['Search rules'] = 'Zoekregels';
$lang['Search tags'] = 'Zoek tags';
$lang['Search'] = 'Zoeken';
$lang['display available tags'] = 'Toon beschikbare tags';
$lang['Since'] = 'Sinds';
$lang['Sort by'] = 'Sorteren op';
$lang['Sort order'] = 'Sorteervolgorde';
$lang['Tag'] = 'Tag';
$lang['Tags'] = 'Tags';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'De RSS feed geeft meldingen als er nieuws is op deze website: nieuwe afbeeldingen, bijgewerkte categorieën, nieuw commentaar. Gebruik hiervoor een rss lezer.';
$lang['Unknown feed identifier'] = 'Onbekende feed identifier';
$lang['User comments'] = 'Gebruikers-commentaar';
$lang['Username'] = 'Gebruikersnaam';
$lang['Visits'] = 'Bezoeken';
$lang['Webmaster'] = 'Webbeheerder';
$lang['Week %d'] = 'Week %d';
$lang['About Piwigo'] = 'Over Piwigo';
$lang['You are not authorized to access the requested page'] = 'U heeft geen rechten tot de opgevraagde pagina';
$lang['add to caddie'] = 'Toevoegen aan winkelmandje';
$lang['add this photo to your favorites'] = 'Voeg deze afbeelding toe aan uw favorieten';
$lang['Administration'] = 'Beheer';
$lang['all'] = 'alle';
$lang['ascending'] = 'Oplopend';
$lang['author(s) : %s'] = 'Maker : %s';
$lang['Expand all albums'] = 'Toon alle categorieën';
$lang['posted after %s (%s)'] = 'geplaatst na %s (%s)';
$lang['posted before %s (%s)'] = 'geplaatst voor %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'geplaatst tussen %s (%s) en %s (%s)';
$lang['posted on %s'] = 'geplaatst op %s';
$lang['Best rated'] = 'Beste gewaardeerd';
$lang['display best rated photos'] = 'Weergeven van de hoogste waardering';
$lang['caddie'] = 'Winkelmandje';
$lang['Calendar'] = 'Kalender';
$lang['All'] = 'Alle';
$lang['display each day with photos, month per month'] = 'Weergeven elke dag met afbeelding, maand per maand';
$lang['View'] = 'Bekijk';
$lang['chronology_monthly_calendar'] = 'Maand-kalender';
$lang['chronology_monthly_list'] = 'Maand-lijst';
$lang['chronology_weekly_list'] = 'Week-lijst';
$lang['Click here if your browser does not automatically forward you'] = 'Klik hier als uw browser u niet doorstuurt';
$lang['comment date'] = 'Commentaar-datum';
$lang['Comment'] = 'Commentaar';
$lang['Your comment has been registered'] = 'Uw commentaar is geregistreerd';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood systeem : u moet even wachten voordat u weer nieuw commentaar kunt plaatsen';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Uw commentaar is NIET geregistreerd omdat de validatie-regels de plaatsing voorkwam';
$lang['An administrator must authorize your comment before it is visible.'] = 'Een beheerder moet uw commentaar goedkeuren voordat het zichtbaar wordt.';
$lang['This login is already used by another user'] = 'Deze gebruikersnaam is al in gebruik';
$lang['Comments'] = 'Commentaar';
$lang['Add a comment'] = 'Voeg commentaar toe';
$lang['created after %s (%s)'] = 'Gemaakt na %s (%s)';
$lang['created before %s (%s)'] = 'Gemaakt voor %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'Gemaakt tussen %s (%s) en %s (%s)';
$lang['created on %s'] = 'gemaakt op %s';
$lang['Customize'] = 'Profiel aanpassen';
$lang['Your Gallery Customization'] = 'Uw galerie aanpassen ';
$lang['day'][0] = 'Zondag';
$lang['day'][1] = 'Maandag';
$lang['day'][2] = 'Dinsdag';
$lang['day'][3] = 'Woensdag';
$lang['day'][4] = 'Donderdag';
$lang['day'][5] = 'Vrijdag';
$lang['day'][6] = 'Zaterdag';
$lang['Default'] = 'Standaard';
$lang['delete this photo from your favorites'] = 'Verwijder deze foto van uw favorieten';
$lang['Delete'] = 'Verwijderen';
$lang['descending'] = 'Aflopend';
$lang['download'] = 'download';
$lang['download this file'] = 'download dit bestand';
$lang['edit'] = 'Wijzig';
$lang['wrong date'] = 'verkeerde datum';
$lang['excluded'] = 'uitsluiten';
$lang['Your favorites'] = 'Mijn favorieten';
$lang['display your favorites photos'] = 'toon mijn favoriete foto\'s';
$lang['Favorites'] = 'Favorieten';
$lang['First'] = 'Eerste';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'De galerie is in onderhoud. Probeer het later nog eens.';
$lang['Page generated in'] = 'Pagina gegenereerd in';
$lang['guest'] = 'gast';
$lang['Hello'] = 'Hallo';
$lang['available for administrators only'] = 'Alleen voor beheerders';
$lang['display this album'] = 'Toont afbeeldingen van het begin van de categorie';
$lang['display last user comments'] = 'Bekijk de laatste gebruikerscommentaren';
$lang['customize the appareance of the gallery'] = 'Weergave van de galerie aanpassen';
$lang['search'] = 'zoeken';
$lang['Home'] = 'Startpagina';
$lang['Identification'] = 'Administratie';
$lang['in this album'] = 'in deze categorie';
$lang['in %d sub-album'] = 'in %d sub-categorie';
$lang['in %d sub-albums'] = 'in %d sub-categorieën';
$lang['included'] = 'inclusief';
$lang['Invalid password!'] = 'Verkeerd wachtwoord!';
$lang['Language'] = 'Taal';
$lang['last %d days'] = 'laaste %d dagen';
$lang['Last'] = 'Laatste';
$lang['Logout'] = 'Loguit';
$lang['E-mail address'] = 'Email-adres';
$lang['obligatory'] = 'verplicht';
$lang['Maximum photo height'] = 'Maximale hoogte van de afbeelding';
$lang['Maximum height must be a number superior to 50'] = 'Maximale hoogte moet meer zijn dan 50';
$lang['Maximum photo width'] = 'Maximale breedte van de afbeelding';
$lang['Maximum width must be a number superior to 50'] = 'Maximale breedte moet meer zijn dan 50';
$lang['display a calendar by creation date'] = 'Toon afbeeldingen gesorteerd op aanmaakdatum';
$lang['display all photos in all sub-albums'] = 'Toon alle afbeeldingen in alle sub-categorieën';
$lang['return to normal view mode'] = 'Terug naar de standaardweergave';
$lang['display a calendar by posted date'] = 'Toon afbeeldingen gesorteerd op plaatsingsdatum';
$lang['month'][10] = 'Oktober';
$lang['month'][11] = 'November';
$lang['month'][12] = 'December';
$lang['month'][1] = 'Januari';
$lang['month'][2] = 'Februari';
$lang['month'][3] = 'Maart';
$lang['month'][4] = 'April';
$lang['month'][5] = 'Mei';
$lang['month'][6] = 'Juni';
$lang['month'][7] = 'Juli';
$lang['month'][8] = 'Augustus';
$lang['month'][9] = 'September';
$lang['Most visited'] = 'Meest bekeken';
$lang['display most visited photos'] = 'Toon de meest bekeken afbeelding';
$lang['The number of photos per page must be a not null scalar'] = 'Het aantal afbeeldingen per pagina mag geen ongeldige deling zijn';
$lang['Number of photos per page'] = 'Aantal afbeeldingen per pagina';
$lang['Unknown identifier'] = 'Onbekend herkenningsteken';
$lang['New password'] = 'Nieuw wachtwoord';
$lang['Rate this photo'] = 'Waardeer deze afbeelding';
$lang['Next'] = 'Volgende';
$lang['no rate'] = 'geen waardering';
$lang['Photos posted within the last %d day.'] = 'Toon alleen afbeeldingen geplaatst in de laatste %s dag.';
$lang['Photos posted within the last %d days.'] = 'Toon alleen afbeeldingen geplaatst in de laatste %s dagen.';
$lang['password updated'] = 'wachtwoord bijgewerkt';
$lang['Recent period must be a positive integer value'] = 'Recente periode moet een positieve waarde zijn';
$lang['photo'] = 'afbeelding';
$lang['Click on the photo to see it in high definition'] = 'Klik op de afbeelding om het te bekijken in een groter formaat';
$lang['Show file metadata'] = 'Toon bestands metadata';
$lang['Powered by'] = 'Powered by';
$lang['Preferences'] = 'Voorkeuren';
$lang['Previous'] = 'Vorige';
$lang['Random photos'] = 'Willekeurige afbeeldingen';
$lang['display a set of random photos'] = 'toon een set van willekeurige afbeeldingen';
$lang['Recent albums'] = 'Recente categorieën';
$lang['display recently updated albums'] = 'toon recentelijk bijgewerkte categorieën';
$lang['Recent period'] = 'Recente periode (aantal dagen)';
$lang['Recent photos'] = 'Recente afbeeldingen';
$lang['display most recent photos'] = 'toon meest recente afbeelding';
$lang['Redirection...'] = 'doorsturen...';
$lang['Please, enter a login'] = 'Vul uw gebruikersnaam in aub.';
$lang['login mustn\'t end with a space character'] = 'Gebruikersnaam mag niet eindigen met een spatie';
$lang['login mustn\'t start with a space character'] = 'Gebruikersnaam mag niet beginnen met een spatie';
$lang['this login is already used'] = 'Deze gebruikersnaam is al in gebruik';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'email-adres moet zijn xxx@yyy.eee (bijvoorbeeld : jack@altern.org)';
$lang['please enter your password again'] = 'vul uw wachtwoord nogmaals in';
$lang['Auto login'] = 'Auto login';
$lang['remove this tag from the list'] = 'Verwijder deze tag van de lijst';
$lang['representative'] = 'representatief';
$lang['Search for Author'] = 'Zoek naar maker';
$lang['Search in albums'] = 'Zoeken in categorieën';
$lang['Search by Date'] = 'Zoeken op datum';
$lang['Date'] = 'Begindatum';
$lang['End-Date'] = 'Einddatum';
$lang['Kind of date'] = 'Datumtype';
$lang['Search for words'] = 'Zoek naar hele woorden';
$lang['Search for all terms'] = 'Zoeken naar alle woorden';
$lang['Search for any terms'] = 'Zoeken naar een woord';
$lang['Empty query. No criteria has been entered.'] = 'Lege zoekopdracht. Er is niets ingevuld.';
$lang['Search Options'] = 'Zoekopties';
$lang['Search results'] = 'Zoekresultaten';
$lang['Search in sub-albums'] = 'Zoeken in sub-categorieën';
$lang['searched words : %s'] = 'zoekwoorden : %s';
$lang['Contact'] = 'Contact';
$lang['set as album representative'] = 'Stel in als standaard categorie';
$lang['Show number of comments'] = 'Toon aantal commentaren';
$lang['Show number of hits'] = 'Toon aantal bezoekers';
$lang['slideshow'] = 'Diavoorstelling';
$lang['stop the slideshow'] = 'Stop de diavoorstelling';
$lang['Specials'] = 'Speciaal';
$lang['SQL queries in'] = 'SQL queries in';
$lang['display only recently posted photos'] = 'Toon alleen de recent geplaatste afbeeldingen';
$lang['return to the display of all photos'] = 'Toon alle afbeeldingen';
$lang['the beginning'] = 'het begin';
$lang['Interface theme'] = 'Thema';
$lang['Thumbnails'] = 'Mini-afbeeldingen';
$lang['Menu'] = 'Menu';
$lang['A comment on your site'] = 'Commentaar op uw site';
$lang['today'] = 'vandaag';
$lang['Update your rating'] = 'Werk uw waardering bij';
$lang['wrong filename'] = 'verkeerde bestandsnaam';
$lang['the username must be given'] = 'de gebruikersnaam moet ingevuld zijn';
$lang['useful when password forgotten'] = 'handig indien u uw wachtwoord bent vergeten';
$lang['Quick search'] = 'Snel zoeken';
$lang['Connected user: %s'] = 'Aangemeld als gebruiker: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Browser: %s';
$lang['Author: %s'] = 'Maker: %s';
$lang['Comment: %s'] = 'Commentaar: %s';
$lang['Comment by %s'] = 'Commentaar van %s';
$lang['User: %s'] = 'Gebruiker: %s';
$lang['Email: %s'] = 'Email: %s';
$lang['Admin: %s'] = 'Beheerder: %s';
$lang['Registration of %s'] = 'Registratie van %s';
$lang['Album: %s'] = 'Categorie: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Foutieve status voor gebruiker "guest", gebruik standaard status. Waarschuw de webbeheerder.';
$lang['this email address is already in use'] = 'Een andere gebruiker maakt al gebruik van dit email-adres';
$lang['Album results for'] = 'Categorie resultaten voor';
$lang['Tag results for'] = 'Tag resultaten voor';
$lang['from %s to %s'] = 'van %s tot %s';
$lang['Play of slideshow'] = 'Diavoorstelling afspelen';
$lang['Pause of slideshow'] = 'Diavoorstelling pauzeren';
$lang['Repeat the slideshow'] = 'Diavoorstelling herhalen';
$lang['Not repeat the slideshow'] = 'Diavoorstelling niet herhalen';
$lang['Reduce diaporama speed'] = 'Diavoorstelling langzamer';
$lang['Accelerate diaporama speed'] = 'Diavoorstelling sneller';
$lang['Submit'] = 'Bevestig';
$lang['Yes'] = 'Ja';
$lang['No'] = 'Nee';
$lang['%d photo']='%d afbeelding';
$lang['%d photos']='%d afbeeldingen';
$lang['%d photo is also linked to current tags'] = '%d afbeelding is ook gelinkt aan de actuele tags';
$lang['%d photos are also linked to current tags'] = '%d afbeeldingen zijn ook gelinkt aan de actuele tags';
$lang['display photos linked to this tag'] = 'Toon afbeeldingen gelinkt met deze tag';
$lang['photos posted during the last %d days'] = 'Afbeelding ontvangen binnen de afgelopen %d dagen';
$lang['Piwigo Help'] = 'Piwigo Help';
$lang['Are you sure?'] = 'Weet u het zeker?';
$lang['delete this comment'] = 'verwijder dit commentaar';
$lang['Rank'] = 'Rang';
$lang['group by letters'] = 'gegroepeerd per letter';
$lang['letters'] = 'letters';
$lang['show tag cloud'] = 'Geef tag-wolk weer';
$lang['cloud'] = 'wolk';
$lang['Reset to default values'] = 'Reset naar standaardwaarden';
$lang['delete all photos from your favorites'] = 'verwijder al de afbeeldingen van uw favorieten';
$lang['Sent by'] = 'Verstuurd door';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Cookies worden geblokkeerd of worden niet ondersteund door uw browser. Om verbinding te kunnen maken dient u er voor te zorgen dat het gebruik van cookies mogelijk is.';
$lang['edit this comment'] = 'Dit commentaar wijzigen';
$lang['Edit a comment'] = 'een commentaar wijzigen';
$lang['(!) This comment requires validation'] = '(!) Dit commentaar moet nog gevakideerd worden';
$lang['Welcome'] = 'Welkom';
$lang['Welcome to your Piwigo photo gallery!'] = 'Welkom bij uw Piwigo fotogalerie!';
$lang['... or browse your empty gallery'] = '... of blader door uw lege galerie';
$lang['... or please deactivate this message, I will find my way by myself'] = '... of deactiveer deze boodschap aub, Ik vind mijn weg zelf wel';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Hallo %s, uw Piwigo fotogalerie is leeg!';
$lang['I want to add photos'] = 'Ik wil afbeeldingen toevoegen';
$lang['Manage this user comment: %s'] = 'Valideer het volgende gebruikers-commentaar: %s';
$lang['This author modified following comment:'] = 'Deze bewerker wijzigde het volgende commentaar:';
$lang['This author removed the comment with id %d'] = 'This author removed the comment with id %d';
$lang['validate this comment'] = 'Valideer dit commentaar';
$lang['html tags are not allowed in login'] = 'html tags zijn niet toegestaan in login';
$lang['%d rates'] = '%d stemmen';
$lang['Rating score'] = 'Waarderings score';
$lang['Enter a username or email address'] = 'Voer je gebruikersnaam en e-mailadres in';
$lang['Invalid username or email'] = 'Gebruikersnaam of e-mailadres is ongeldig';
$lang['Password reset is not allowed for this user'] = 'Deze gebruiker heeft geen toestemming om het paswoord te vernieuwen';
$lang['User "%s" has no email address, password reset is not possible'] = 'Gebruiker "%s" heeft geen e-mailadres daarom kan het paswoord niet vernieuwd worden';
$lang['Someone requested that the password be reset for the following user account:'] = 'Iemand heeft verzocht om het paswoord te vernieuwen voor het volgende account:';
$lang['Username "%s" on gallery %s'] = 'Gebruikersnaam "%s" voor gallery %s';
$lang['To reset your password, visit the following address:'] = 'Om je paswoord te vernieuwen kun je het volgende adres bezoeken:';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'Als dit een vergissing was kun je deze e-mail negeren, er zal dan niets gewijzigd worden.';
$lang['Password Reset'] = 'Vernieuw paswoord';
$lang['Check your email for the confirmation link'] = 'Kijk in je mail box voor de bevestigings link';
$lang['Invalid key'] = 'Onjuiste sleutel';
$lang['The passwords do not match'] = 'De paswoorden zijn niet gelijk';
$lang['Your password has been reset'] = 'Je paswoord is vernieuwd';
$lang['Return to home page'] = 'Keer terug naar de home page';
$lang['Please enter your username or email address.'] = 'Voer je gebruikersnaam en e-mailadres in.';
$lang['You will receive a link to create a new password via email.'] = 'Via e-mail krijg je een link om je paswoord te vernieuwen.';
$lang['Username or email'] = 'Gebruikersnaam of e-mail';
$lang['Change my password'] = 'Vernieuw mijn paswoord';
$lang['Enter your new password below.'] = 'Voer hieronder je nieuwe paswoord in.';
$lang['Reset Password'] = 'Vernieuw Paswoord';
$lang['EXIF Metadata'] = 'EXIF Metagegevens';
$lang['IPTC Metadata'] = 'IPTC Metagegevens';

?>